@@ -107,7 +107,7 @@ class OptionConstantsTest(unittest.TestCase):
 
     # CURLOPT_SOCKS5_GSSAPI_NEC was introduced in libcurl-7.19.4
     @util.min_libcurl(7, 19, 4)
-    @pytest.mark.gssapi
+    @util.only_gssapi
     def test_socks5_gssapi_nec_setopt(self):
         curl = pycurl.Curl()
         curl.setopt(curl.SOCKS5_GSSAPI_NEC, True)
@@ -442,7 +442,7 @@ class OptionConstantsTest(unittest.TestCase):
         curl.close()
 
     @util.min_libcurl(7, 52, 0)
-    @util.only_ssl
+    @util.only_ssl_backends('openssl', 'schannel', 'secure-transport', 'mbedtls', 'wolfssl')
     def test_proxy_ssl_cipher_list(self):
         curl = pycurl.Curl()
         curl.setopt(curl.PROXY_SSL_CIPHER_LIST, 'RC4-SHA:SHA1+DES')
@@ -462,7 +462,6 @@ class OptionConstantsTest(unittest.TestCase):
     @util.only_ssl_backends('openssl', 'gnutls', 'schannel')
     def test_proxy_tlsauth(self):
         curl = pycurl.Curl()
-        curl.setopt(curl.PROXY_TLSAUTH_TYPE, "SRP")
         curl.setopt(curl.PROXY_TLSAUTH_USERNAME, "test")
         curl.setopt(curl.PROXY_TLSAUTH_PASSWORD, "test")
         curl.close()
@@ -492,7 +491,7 @@ class OptionConstantsTest(unittest.TestCase):
         curl.setopt(curl.EGDSOCKET, '/bogus-egdsocket')
         curl.close()
 
-    @util.only_ssl
+    @util.only_ssl_backends('openssl', 'schannel', 'secure-transport', 'mbedtls', 'wolfssl')
     def test_ssl_cipher_list(self):
         curl = pycurl.Curl()
         curl.setopt(curl.SSL_CIPHER_LIST, 'RC4-SHA:SHA1+DES')
@@ -504,11 +503,13 @@ class OptionConstantsTest(unittest.TestCase):
         curl.setopt(curl.SSL_SESSIONID_CACHE, True)
         curl.close()
 
+    @util.only_gssapi
     def test_krblevel(self):
         curl = pycurl.Curl()
         curl.setopt(curl.KRBLEVEL, 'clear')
         curl.close()
 
+    @util.only_gssapi
     def test_krb4level(self):
         curl = pycurl.Curl()
         curl.setopt(curl.KRB4LEVEL, 'clear')
@@ -560,6 +561,12 @@ class OptionConstantsTest(unittest.TestCase):
         curl.setopt(curl.AWS_SIGV4, 'provider1:provider2')
         curl.close()
 
+    @util.min_libcurl(8, 2, 0)
+    def test_haproxy_client_ip(self):
+        curl = pycurl.Curl()
+        curl.setopt(curl.HAPROXY_CLIENT_IP, '192.0.2.22')
+        curl.close()
+
 class OptionConstantsSettingTest(unittest.TestCase):
     def setUp(self):
         self.curl = pycurl.Curl()
@@ -668,6 +675,11 @@ class OptionConstantsSettingTest(unittest.TestCase):
     def test_http_version_3(self):
         self.curl.setopt(self.curl.HTTP_VERSION, self.curl.CURL_HTTP_VERSION_3)
 
+    @util.min_libcurl(7, 88, 0)
+    @util.only_http3
+    def test_http_version_3only(self):
+        self.curl.setopt(self.curl.HTTP_VERSION, self.curl.CURL_HTTP_VERSION_3ONLY)
+
     @util.min_libcurl(7, 21, 5)
     def test_sockopt_constants(self):
         assert self.curl.SOCKOPT_OK is not None
